# Jsonp to json (jsonp格式转换json格式)

Similar to the JSON library, it is used to convert the JSON format into JSON format.
它与json库类似，作用是将jsonp格式转换为json格式。

### Install

pip install jsonp2

### Example1

jsonp:jQuery1122012033111883315373_1662703989030({"a":1,"b":2})
jsonp to json:{"a":1,"b":2}

### Example2

jsonp:jsonCallback1122012033111883315373_1662703989030({"a":1,"b":2})
jsonp to json:{"a":1,"b":2}

### Example2

jsonp:jsonp1122012033111883315373_1662703989030({"a":1,"b":2})
jsonp to json:{"a":1,"b":2}